@@ -11,13 +11,14 @@ class Lookahead(Controller):
 
     def feed(self, state, t):
         dt = self.dt(t)
+        cycle_phase = self.cycle_phase(t)
 
         controller_copy = copy.deepcopy(self.base_controller)
         self.forecast_model.update(state)
         u_in = 0
         for i in range(self.lookahead_steps):
             lookahead_state = self.forecast_model.predict(i)
-            u_in = controller_copy.feed(lookahead_state, t + i * dt)
+            u_in = controller_copy.feed(lookahead_state, cycle_phase + i * dt)
 
-        self.base_controller.feed(state, t)
-        return (u_in, self.u_out(t))
+        self.base_controller.feed(state, cycle_phase)
+        return (u_in, self.u_out(cycle_phase))
