@@ -22,3 +22,8 @@ class Environment(abc.ABC):
     @abc.abstractmethod
     def step(self, u_in, u_out, t):
         pass
+
+    def dt(self, t):
+        dt = max(0, t - self.time)
+        self.time = t
+        return dt
